pub enum UserVerificationMethod {
None,
PresenceInternal,
PasscodeInternal(Option<CodeAccuracyDescriptor>),
PasscodeExternal(Option<CodeAccuracyDescriptor>),
FingerprintInternal(Option<BiometricAccuracyDescriptor>),
HandprintInternal(Option<BiometricAccuracyDescriptor>),
EyeprintInternal(Option<BiometricAccuracyDescriptor>),
VoiceprintInternal(Option<BiometricAccuracyDescriptor>),
FaceprintInternal(Option<BiometricAccuracyDescriptor>),
LocationInternal,
PatternInternal(Option<PatternAccuracyDescriptor>),
}Expand description
An identifier of a user verification method. Some methods may contain an internal descriptor which provides information about certification or details of the user verification method.
Variants
None
No user verification is required
PresenceInternal
Physical interaction is required i.e. touching the device. The identity of whom touched the device is NOT asserted, only that someone touched it.
PasscodeInternal(Option<CodeAccuracyDescriptor>)
A passcode was entered internally to the device, i.e. a self contained PIN entry pad embedded into the device.
PasscodeExternal(Option<CodeAccuracyDescriptor>)
A password was supplied to the device from an external source, i.e. a PIN entry dialog in a browser, that then supplied the PIN to the device.
FingerprintInternal(Option<BiometricAccuracyDescriptor>)
A fingerprint reader that is built into the device.
HandprintInternal(Option<BiometricAccuracyDescriptor>)
A Handprint reader that is built into the device.
EyeprintInternal(Option<BiometricAccuracyDescriptor>)
A Handprint reader that is built into the device.
VoiceprintInternal(Option<BiometricAccuracyDescriptor>)
A Voiceprint reader that is built into the device.
FaceprintInternal(Option<BiometricAccuracyDescriptor>)
A Faceprint reader that is built into the device.
LocationInternal
Unknown - No definition is available.
PatternInternal(Option<PatternAccuracyDescriptor>)
A pattern was entered internally to the device, i.e. a 3x3 grid of dots on a display that the user traces over on a touch screen.